@@ -1,12 +1,10 @@
 package DateTimeX::Mashup::Shiras;
-BEGIN {
-  $DateTimeX::Mashup::Shiras::AUTHORITY = 'cpan:JANDREW';
-}
-use version 0.77; our $VERSION = qv("v0.32.8");
+our $AUTHORITY = 'cpan:JANDREW';
+use version 0.77; our $VERSION = qv("v0.34.2");
 
 if( $ENV{ Smart_Comments } ){
 	use Smart::Comments -ENV;
-	### <where> - Smart-Comments turned on for DateTimeX-Mashup-Shiras v0.31
+	### <where> - Smart-Comments turned on for DateTimeX-Mashup-Shiras: $VERSION
 }
 
 use 5.010;
@@ -189,13 +187,29 @@ DateTimeX::Mashup::Shiras - A Moose role with date attributes
 
 =begin html
 
-<a href="https://travis-ci.org/jandrew/DateTimeX-Mashup-Shiras"><img alt="Build Status" src="https://travis-ci.org/jandrew/DateTimeX-Mashup-Shiras.png?branch=master" alt='Travis Build'/></a>
+<a href="https://www.perl.org">
+	<img src="https://img.shields.io/badge/perl-5.10+-brightgreen.svg" alt="perl version">
+</a>
 
-<a href="https://www.perl.org"><img src="https://img.shields.io/badge/perl-5.10+-brightgreen.svg" alt="perl version"></a>
+<a href="https://travis-ci.org/jandrew/DateTimeX-Mashup-Shiras">
+	<img alt="Build Status" src="https://travis-ci.org/jandrew/DateTimeX-Mashup-Shiras.png?branch=master" alt='Travis Build'/>
+</a>
 
-<a href='https://coveralls.io/r/jandrew/DateTimeX-Mashup-Shiras?branch=master'><img src='https://coveralls.io/repos/jandrew/DateTimeX-Mashup-Shiras/badge.svg?branch=master' alt='Coverage Status' /></a>
+<a href='https://coveralls.io/r/jandrew/DateTimeX-Mashup-Shiras?branch=master'>
+	<img src='https://coveralls.io/repos/jandrew/DateTimeX-Mashup-Shiras/badge.svg?branch=master' alt='Coverage Status' />
+</a>
 
-<a href='http://cpants.cpanauthors.org/dist/DateTimeX-Mashup-Shiras'><img src='http://cpants.cpanauthors.org/dist/DateTimeX-Mashup-Shiras.png' alt='kwalitee' height="20"/></a>
+<a>
+	<img src="https://img.shields.io/badge/this version-0.32.10-brightgreen.svg" alt="this version">
+</a>
+
+<a href="https://metacpan.org/pod/DateTimeX::Mashup::Shiras">
+	<img src="https://badge.fury.io/pl/DateTimeX-Mashup-Shiras.svg?label=cpan version" alt="CPAN version" height="20">
+</a>
+
+<a href='http://cpants.cpanauthors.org/dist/DateTimeX-Mashup-Shiras'>
+	<img src='http://cpants.cpanauthors.org/dist/DateTimeX-Mashup-Shiras.png' alt='kwalitee' height="20"/>
+</a>
 
 =end html
 
@@ -455,7 +469,7 @@ it and/or modify it under the same terms as Perl itself.
 The full text of the license can be found in the
 LICENSE file included with this module.
 
-This software is copyrighted (c) 2013, 2014 by Jed Lund.
+This software is copyrighted (c) 2013, 2015 by Jed Lund.
 
 =head1 DEPENDENCIES
 
